ziggy.GraphReduce.gr_link_analysis

Package ziggy :: Package GraphReduce :: Module gr_link_analysis |
[hide private]
[frames] | no frames]

# Module gr_link_analysis

source code

Created on Aug 18, 2010

Author: dwmclary

Functions | [hide private]
page_rank(G, name=None, max_iterations=10) Compute page rank in parallel for the networkx graph G. | source code
parallel_page_rank(G, hdfs_handle, old_ranks, iterations, max_iterations) Compute page rank in parallel for the networkx graph G. | source code

Variables | [hide private]
| __author__ = ``'``D. McClary (dan.mcclary@northwestern.edu)``'``
| __package__ = ``'``ziggy.GraphReduce``'``